:mod:`~arcs.gsi.certficate` -- Handle certificates and requests
==============================================================

.. _ref-certificate

.. module:: arcs.gsi.certificate
.. moduleauthor:: Russell Sim <russell@vpac.org>


:class:`CertificateRequest` Objects
-----------------------------------
.. autoclass:: CertificateRequest
   :members:
   :undoc-members:


:class:`Certificate` Objects
----------------------------
.. autoclass:: Certificate
   :members:
   :undoc-members:

.. seealso::

    Class :class:`~arcs.gsi.key.Key`
        a class that is used by the certificate classes to handle the key pairs

